@@ -7,6 +7,7 @@ use JSON::XS;
 sub ajax_ok {
     my ($self, $path, $args, $expected, $message, $dump) = @_;
     $message = ($message ? " - $message" : '');
+    $dump ||= $ENV{AUTOCRUD_TEST_DUMP};
 
     my $post = $self->post_ok( $path, $args, 'POST'. $message );
     my $ct = is( $self->ct, 'application/json', 'AJAX content type'. $message );
@@ -15,7 +16,11 @@ sub ajax_ok {
 
     if ($dump) {
         use Data::Dumper;
-        print STDERR Dumper [$response, $expected];
+        print STDERR Dumper [
+            ($dump > 0 ? $self->content : ()),
+            ($dump > 1 ? $response : ()),
+            ($dump > 2 ? $expected : ()),
+        ];
     }
     my $id = is_deeply( $response, $expected, 'AJAX JSON data compare'. $message );
 
